/**
 * COPYRIGHT 2023 Flirc, Inc. All rights reserved.
 *
 * This copyright notice is Copyright Management Information under 17 USC 1202
 * and is included to protect this work and deter copyright infringement.
 * Removal or alteration of this Copyright Management Information without
 * the express written permission of Flirc, Inc. is prohibited, and any
 * such unauthorized removal or alteration will be a violation of federal law.
 *
 * @file
 * @brief   Flirc Library functions
 */

#include <stdint.h>

#ifndef I__FLIRC_SUDO_H__
	#define I__FLIRC_SUDO_H__

#ifdef __cplusplus
extern "C" {
#endif /* __cpluspuls */

#ifdef BUILD_DLL
  #ifdef _DLL
    #undef _DLL
    #define _DLL __declspec(dllexport)
  #else
    #define _DLL __declspec(dllexport)
  #endif
#else
  #ifdef _DLL
    #undef _DLL
    #define _DLL
  #else
    #define _DLL
  #endif
#endif

/**
 * fl_mfg_set_tested() sets the tested bit.
 *
 * This function requires no arguments.
 *
 * @return	-ENODEV		- Flirc not present
 * @return	-LIBUSBERR	- LIBUSB error code
 * @return	-EWRONGDEV	- Unsupported, device in bootloader
 */
int _DLL fl_mfg_set_tested(void);

/**
 * fl_mfg_get_tested() sets the tested bit.
 *
 * This function requires no arguments.
 *
 * @return	0:1		 (not tested/tested)
 * @return	-ENODEV		- Flirc not present
 * @return	-LIBUSBERR	- LIBUSB error code
 * @return	-EWRONGDEV	- Unsupported, device in bootloader
 */
int _DLL fl_mfg_get_tested(void);

/**
 * fl_get_uuid() gets the unique serial number of the device
 *
 * @param buf  - pointer to buffer to fil
 * @param len  - length of buffer to make sure we don't overflow
 *
 * @return	-ENODEV		- Flirc not present
 * @return	-LIBUSBERR	- LIBUSB error code
 * @return	-EWRONGDEV	- Unsupported, device in bootloader
 */
int _DLL fl_get_uuid(uint32_t *buf, size_t len);

/**
 * fl_get_header() gets the header of the device. Mainly for printing
 *
 * This function requires no arguments.
 *
 * @return	-NULL		- Probably no device
 * @return	string		- 100 bytes of header
 */
uint8_t * _DLL fl_get_header(void);

/**
 * fl_send_cmd() send a raw command for testing purposes
 *
 * @param cmd  - string for command name
 * @param buf  - pointer to buffer to fil
 * @param len  - length of buffer to make sure we don't overflow
 *
 * @return	buf		- raw response
 * @return	-ENODEV		- Flirc not present
 * @return	-LIBUSBERR	- LIBUSB error code
 * @return	-EWRONGDEV	- Unsupported, device in bootloader
 */
int _DLL fl_send_cmd(const char *cmd, uint8_t *buf, size_t len);

#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif /* I__FLIRC_SUDO_H__ */

